__author__ = 'jeff'

import __builtin__ as builtins

# umm... getting an attribute error?
# try:
#     builtins.profile
# except AttributeError:
builtins.profile = lambda x: x

import collections
from functools32 import wraps, lru_cache
import errno
import os
import signal

# https://github.com/opengm/opengm/issues/453
# import networkx
# from networkx.drawing.nx_agraph import graphviz_layout
# networkx.graphviz_layout = graphviz_layout

args = None


# cite: http://stackoverflow.com/questions/9997176/immutable-dictionary-only-use-as-a-key-for-another-dictionary/9997519#9997519
class ImmutableDict(collections.Mapping):
    def __init__(self, somedict):
        self._dict = dict(somedict)  # make a copy
        self._hash = None

    def __getitem__(self, key):
        return self._dict[key]

    def __len__(self):
        return len(self._dict)

    def __iter__(self):
        return iter(self._dict)

    def __hash__(self):
        if self._hash is None:
            self._hash = hash(frozenset(self._dict.items()))
        return self._hash

    def __eq__(self, other):
        if isinstance(other, dict):
            return self._dict == other

        return self._dict == other._dict

    def __cmp__(self, other):
        return self._dict.__cmp__(other._dict)

    def __str__(self):
        return self._dict.__str__()

    def __repr__(self):
        return self._dict.__repr__()


def log_time(name=None):
    def real_decorator(func):
        log_name = name if name is not None else func.__name__

        def wrapper(*args, **kwargs):
            logging.info('Running %s...' % log_name)
            start_time = time.time()
            retval = func(*args, **kwargs)
            end_time = time.time()
            logging.info('%s took %s seconds' % (log_name, str(end_time - start_time)))
            return retval

        return wrapper

    return real_decorator


def zip_equal(it1, it2):
    assert len(it1) == len(it2)
    return zip(it1, it2)


# cite: http://stackoverflow.com/questions/2281850/timeout-function-if-it-takes-too-long-to-finish
class TimeoutError(Exception):
    pass


def timeout(seconds=10, error_message=os.strerror(errno.ETIME)):
    def decorator(func):
        def _handle_timeout(signum, frame):
            raise TimeoutError(error_message)

        def wrapper(*args, **kwargs):
            signal.signal(signal.SIGALRM, _handle_timeout)
            signal.alarm(seconds)
            try:
                result = func(*args, **kwargs)
            finally:
                signal.alarm(0)
            return result

        return wraps(func)(wrapper)

    return decorator


# todo these are exported, not unused
# but this isn't how to do it
# __all__ = ['config', 'dataset', 'protein_network', 'gene_ontology', 'annotation', 'bayes_net', 'evaluation', 'inference', 'protein_network_parent', 'prediction', 'label', 'uniprot']

from sqlalchemy.ext.declarative import declarative_base
EffusionBase = declarative_base()

import config
import dataset
import protein_network

from gene_ontology import *
from annotation import *
from bayes_net import *
from evaluation import *
from inference import *
from protein_network_parent import *
from prediction import *
from label import *
from uniprot import *




# why? this and not just BFS? because this lets me easily get the parent.
# todo(jyunes) but maybe i shouldn't have lost it in the first place
def as_directed(g, root_vid):
    assert g.is_connected(mode=igraph.WEAK)
    assert not any(g.is_loop())
    assert g.is_simple()

    topological_order = g.bfs(root_vid, mode='any')[0]
    vid_to_topo_index = {vid: i for i, vid in enumerate(topological_order)}

    directed_edges = []
    for e in g.es:
        if vid_to_topo_index[e.source] < vid_to_topo_index[e.target]:
            directed_edges.append((e.source, e.target))
        else:
            directed_edges.append((e.target, e.source))

    # todo(jyunes) check. improve

    gattrs, vattrs, eattrs = {}, {}, {}
    for attr in g.attributes():
        gattrs[attr] = g[attr]
    for attr in g.vs.attribute_names():
        vattrs[attr] = g.vs[attr]
    for attr in g.es.attribute_names():
        eattrs[attr] = g.es[attr]

    retval = igraph.Graph(n=g.vcount(),
                          edges=directed_edges,
                          directed=True,
                          graph_attrs=gattrs,
                          vertex_attrs=vattrs,
                          edge_attrs=eattrs
                          )

    return retval


# todo(jyunes) "very similar" to the prop downward for prediction
@lru_cache(maxsize=None)
def term_prior(go_id):
    go_vertex = effusion.dataset.gene_ontology.vertex4id(go_id)
    ancestor_vertices = effusion.dataset.gene_ontology.get_ancestors(go_vertex)

    # todo(jyunes) could store the marginals at each node to make this faster (each term would be parent prob * conditional prob)
    prob = 1
    for ancestor_vertex in ancestor_vertices:
        ancestor_go_id = ancestor_vertex['name']

        prob *= effusion.dataset.go_hierarchy_params[ancestor_go_id]

    return prob
