import logging
import sys
import uuid

import configargparse
import os
import re

import effusion

sys.stderr.write('cwd: %s\n' % os.getcwd())

# prevent using hashdbm on linux so it can be used on mac
import anydbm

anydbm._defaultmod = __import__('gdbm')


def get_argument_parser():
    default_config_path = os.path.join(os.path.dirname(os.path.dirname(unicode(__file__, sys.getfilesystemencoding()))),
                                       'etc', 'defaults.cfg')
    p = configargparse.get_argument_parser(default_config_files=[default_config_path, '~/etc/effusion.cfg'])

    p.add('--app_dir')
    p.add('--num_cpus', type=int)
    p.add('--log_to_stderr', action='store_true')

    # p.add('--write_visual_files', type=bool) will return True if set to False because...
    # ... bool('False') and bool('0') both evaluate to True
    # however, if you do a "store true" then the overriding config file will be processed first, and option = False will just be ignored.
    # as a result, the default.cfg, which is processed later, will be used. so let's just not put it in the default, and use store_true to be a default false
    p.add('--no_write_visual_files', action='store_true')
    p.add('--data_dir')
    p.add('--tmp_dir')
    p.add('--experiment_name')
    p.add('--no_weighted_counts', action='store_true')
    p.add('--remove_tmp_files', action='store_true')
    p.add('--top_down_or_bottom_up')
    p.add('--pseudocount_weight', type=float)
    p.add('--max_num_iterations', type=int)
    p.add('--max_num_proteins', type=int)
    p.add('--uniref_for_blast', default=None)
    p.add('--max_target_seqs', type=int)
    p.add('--min_bit_score_per_residue', type=float)
    p.add('--evalue', type=float)
    p.add('--blastp_bin')
    p.add('--blastdbcmd_bin')
    p.add('--makeblastdb_bin')
    p.add('--diamond_bin')
    p.add('--blast_score_multiplier', type=float)
    p.add('--min_query_cover', type=float)
    p.add('--uniref_100_blast_db')
    p.add('--uniref_100_diamond_db')
    p.add('--uniref_90_blast_db')
    p.add('--uniref_90_diamond_db')
    p.add('--uniref_50_blast_db')
    p.add('--uniref_50_diamond_db')
    p.add('--uniprot_db')
    p.add('--uniprot_diamond_db')
    p.add('--min_string_score', type=int)
    p.add('--protein_aliases')
    p.add('--string_score_multiplier', type=float)
    p.add('--max_string_proteins', type=int)
    p.add('--min_functions_per_ontology', type=int)
    p.add('--max_valid_states', type=int)
    p.add('--max_valid_states_per_ontology', type=int)
    p.add('--uniref_for_evidence', default=None)
    p.add('--uai_solver')
    p.add('--use_libdai', action='store_true')
    p.add('--libdai_alg')
    p.add('--max_time', type=int)
    p.add('--num_interontological_parents', type=int)
    p.add('--add_inferred_negative_annotations')

    return p


def parse_args(parser):
    args = parser.parse_args()

    # interpolate
    # this re captures the interpolation key, plus the %(key)s stuff around it. makes it possible to replace the whole thing with re.sub()
    r = re.compile(r'(%\(\w+\)s)')

    def repl(m):
        interpolation_key = m.group(1)[2:-2]
        interpolation_value = args.__dict__[interpolation_key]
        return interpolation_value

    for k, v in args.__dict__.iteritems():
        if not isinstance(v, str):
            continue
        processed_v = r.sub(repl, v)
        args.__dict__[k] = processed_v

    log_filename = None
    if not args.log_to_stderr:
        log_filename = 'effusion.' + str(uuid.uuid1()) + '.log'
    log_level = logging.DEBUG
    assert len(logging.root.handlers) == 0  # if a logger has already been setup, basicConfig does nothing
    logging.basicConfig(filename=log_filename, level=log_level, filemode="w")

    logging.getLogger('sqlalchemy.engine').setLevel(logging.WARNING)
    # logging.getLogger('sqlalchemy.engine').setLevel(logging.INFO)  # print queries

    assert args.num_cpus == None or (1 <= args.num_cpus <= 32)

    # todo(jyunes) warn if min(combined_score) < min_string_score

    # todo side effects all over the place
    effusion.args = args
    return args


sys.setrecursionlimit(20000)
max_display_edges = 200000
display_p_annotation_or_function = 'annotation'
