import effusion


# Definitions!!!!
# Label is in the sense of machine learning. Each sample has a label.
# This is a structured-output multi-label, and may be incomplete.
# It may be restricted to a subset of the annotations (the enriched ones), particularly when propagating downward
# A label is made up of partial labels that are either True or False.
# There is only one partial label per... partial label. I.e., a sample may not have conflicting partial labels.
# Therefore, it is a dictionary.

# todo(jyunes) Eh, since methods may want to see the various annotations / probs, maybe they should take annotations rather than labels



class Label(effusion.ImmutableDict):
    def __init__(self,
                 gene_ontology,
                 all_annotations,
                 add_uif=False,
                 catalytic_only=False,
                 mf_only=False,
                 bp_only=False):
        """
        :param annotations: The "raw" evidence
        :param relevant_go_ids: After we propagate down (/ up), restrict our label to these terms
        :param args:
        :param kwargs:
        """
        if all_annotations is None:
            all_annotations = []

        relevant_go_ids = {v['name'] for v in gene_ontology.vs}
        relevant_annotations = [a for a in all_annotations if a.go_id in relevant_go_ids]

        label_dict = {}
        for annotation in relevant_annotations:
            go_term = gene_ontology.term4id(annotation.go_id)
            # Don't continue if go_term is not None. We might be playing with GO:0...
            if catalytic_only and not go_term.catalytic:
                continue
            if mf_only and go_term.aspect != effusion.GoAspectEnum.molecular_function:
                continue
            if bp_only and go_term.aspect != effusion.GoAspectEnum.biological_process:
                continue
            if isinstance(annotation, effusion.QuickPred):
                val = True
            else:
                val = annotation.value
            label_dict[annotation.go_id] = val

        if add_uif:
            positive_go_ids = {a.go_id for a in all_annotations if a.value}
            negative_go_ids = gene_ontology.imply_negative_uif_go_ids(positive_go_ids)
            for negative_go_id in negative_go_ids:
                label_dict[negative_go_id] = False

        super(Label, self).__init__(label_dict)

        # self.relevant_annotations = relevant_annotations
        # self.catalytic_only = catalytic_only

    def get_ic(self):
        pass
