After installing, specify one of the phases:

* `export PHASE=discovery`
* `export PHASE=test`
* `export PHASE=prediction`

SGE batch operations require the task range

```
if [ $PHASE == 'discovery' ]  # then lets not get carried away
    then
        export NUM_QUERIES=1000
    else
        export NUM_QUERIES=`cat $CLUSTER_DATA_DIR/evaluation_proteins.$PHASE.txt | wc -l`
fi
```

# Build networks
## Single protein

    $CLUSTER_PYTHON $EFFUSION_DIR/bin/effuse.py $CLUSTER_DATA_DIR $PHASE build --query-uniprot Q9JIL8 direct_net

## On the cluster

    qsub -t 1-$NUM_QUERIES -v dataset=$DATA_DIR -v phase=$PHASE $EFFUSION_DIR/bin/build.sge


# Predict
## Single protein

## On the cluster


### Baselines

    qsub -t 1-$NUM_QUERIES $EFFUSION_DIR/bin/predict.sge $CLUSTER_DATA_DIR $PHASE effusion.BlastMethod

    qsub -t 1-$NUM_QUERIES $EFFUSION_DIR/bin/predict.sge $CLUSTER_DATA_DIR $PHASE effusion.RandomBlastMethod

### Effusion

    export BUILD_JID=18216

    export TD_OPT=--top_down_or_bottom_up top_down
    export BU_OPT=--top_down_or_bottom_up bottom_up

    export MOONLIGHT_OPT=--add_inferred_negative_annotations moonlight
    export NONEGS_OPT=--add_inferred_negative_annotations none

    export IJGP_OPT=--uai_solver \"$HOME/software/ijgp --i-bound 6 --num-iterations 14 {uai_file_path} {evid_file_path}\"
    export SAMPLESEARCH_OPT=--uai_solver \"$HOME/software/ijgp-samplesearch -i 6 -n 14 {uai_file_path} {evid_file_path} {max_seconds} MAR\"
    export AI_OPT=--uai_solver \"$HOME/software/ai_solvers/solvers/uai14 -f {uai_file_path} -e {evid_file_path} -T MAR -m 8000 --lbps 300 -o $NUM_QUERIES -t 100 --order-rand 3 --gbps $NUM_QUERIES --dt 180 -i 20\"
    export AI_COND_OPT=--uai_solver \"$HOME/software/ai_solvers/solvers/uai14 -f {uai_file_path} -e {evid_file_path} -T MAR -m 8000 --lbps 300 -o 1000 -t 100 --order-rand 3 --gbps 1000 --dt 180 -i 20 --condition 1\"
    export AI_IJGP_OPT=--uai_solver \"$HOME/software/ai_solvers/solvers/uai14 -f {uai_file_path} -e {evid_file_path} -T MAR -m 8000 --lbps 300 -o $NUM_QUERIES -t 100 --order-rand 3 --gbps $NUM_QUERIES --dt 180 -i 20 --ijgp\"
    export AI_IJGP_COND_OPT=--uai_solver \"$HOME/software/ai_solvers/solvers/uai14 -f {uai_file_path} -e {evid_file_path} -T MAR -m 8000 --lbps 300 -o $NUM_QUERIES -t 100 --order-rand 3 --gbps $NUM_QUERIES --dt 180 -i 20 --condition 1 --ijgp\"
    export WMBIS_OPT=--uai_solver \"$HOME/software/ai_solvers/solvers/uai16_wmbis -f {uai_file_path} -e {evid_file_path} -t 100 -o $NUM_QUERIES --order-rand 3 -m 8000 -T MAR -n 20 --stoptime 180 -s 1e6 --sampletime 1800 --write 1\"
    export BP_OPT=--use_libdai --libdai_alg "BP[inference=SUMPROD,updates=SEQMAX,logdomain=0,tol=1e-9,maxiter=$NUM_QUERIES0,damping=.1,verbose=3]"
    export TRWBP_OPT=--use_libdai --libdai_alg 'TRWBP[inference=SUMPROD,updates=SEQRND,logdomain=1,tol=1e-9,maxiter=$NUM_QUERIES0,damping=.1,nrtrees=0,verbose=3]'
    export GLC_OPT=--use_libdai --libdai_alg 'GLC[verbose=3,rgntype=SINGLE,cavity=PAIR,updates=SEQRND,maxiter=$NUM_QUERIES0,tol=1e-9,cavainame=BP,cavaiopts=[updates=SEQMAX,tol=1e-9,maxiter=$NUM_QUERIES0,logdomain=1],inainame=EXACT,inaiopts=[],tol=1e-9]'
    export NULL_SOLVER_OPT=--uai_solver \"$CLUSTER_PYTHON $EFFUSION_DIR/bin/null_uai_solver.py {uai_file_path}\"

#### Just get some statistics

    qsub -t 1-$NUM_QUERIES $EFFUSION_DIR/bin/predict.sge --max_time 10 --experiment_name "collect_stats" $TD_OPT $NONEGS_OPT $NULL_SOLVER_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod

#### uai methods

    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "td.ijgp" $TD_OPT $MOONLIGHT_OPT $IJGP_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod
    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "bu.ijgp" $BU_OPT $NONEGS_OPT $IJGP_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod
    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "td.samplesearch" $TD_OPT $MOONLIGHT_OPT $SAMPLESEARCH_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod
    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "bu.samplesearch" $BU_OPT $NONEGS_OPT $SAMPLESEARCH_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod

    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "td.ai" $TD_OPT $MOONLIGHT_OPT $AI_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod
    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "bu.ai" $BU_OPT $NONEGS_OPT $AI_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod

    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "td.ai_cond" $TD_OPT $MOONLIGHT_OPT $AI_COND_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod
    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "bu.ai_cond" $BU_OPT $NONEGS_OPT $AI_COND_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod

    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "td.ai_ijgp" $TD_OPT $MOONLIGHT_OPT $AI_IJGP_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod
    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "bu.ai_ijgp" $BU_OPT $NONEGS_OPT $AI_IJGP_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod

    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "td.ai_ijgp_cond" $TD_OPT $MOONLIGHT_OPT $AI_IJGP_COND_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod
    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "bu.ai_ijgp_cond" $BU_OPT $NONEGS_OPT $AI_IJGP_COND_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod

    # qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "td.wmbis" $TD_OPT $MOONLIGHT_OPT $WMBIS_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod
    # qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "bu.wmbis" $BU_OPT $NONEGS_OPT $WMBIS_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod


#### libdai methods

    qsub -t 1-$NUM_QUERIES $EFFUSION_DIR/bin/predict.sge --experiment_name "td.bp" $TD_OPT $MOONLIGHT_OPT $BP_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod
    qsub -t 1-$NUM_QUERIES $EFFUSION_DIR/bin/predict.sge --experiment_name "bu.bp" $BU_OPT $NONEGS_OPT $BP_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod

    qsub -t 1-$NUM_QUERIES $EFFUSION_DIR/bin/predict.sge --experiment_name "td.trwbp" $TD_OPT $MOONLIGHT_OPT $TRWBP_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod
    qsub -t 1-$NUM_QUERIES $EFFUSION_DIR/bin/predict.sge --experiment_name "bu.trwbp" $BU_OPT $NONEGS_OPT $TRWBP_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod

    qsub -t 1-$NUM_QUERIES $EFFUSION_DIR/bin/predict.sge --experiment_name "td.glc" $TD_OPT $MOONLIGHT_OPT $GLC_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod
    qsub -t 1-$NUM_QUERIES $EFFUSION_DIR/bin/predict.sge --experiment_name "bu.glc" $BU_OPT $NONEGS_OPT $GLC_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod


#### Not adding negative annotations

    qsub -t 1-$NUM_QUERIES $EFFUSION_DIR/bin/predict.sge --experiment_name "td.ai_cond.no_more_negs" $TD_OPT $NONEGS_OPT $AI_COND_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod


#### Not using the network / unlabeled data

    qsub -t 1-$NUM_QUERIES $EFFUSION_DIR/bin/predict.sge $TD_OPT $MOONLIGHT_OPT $AI_COND_OPT $CLUSTER_DATA_DIR $PHASE effusion.BlastLikeMethod

    qsub -t 1-$NUM_QUERIES $EFFUSION_DIR/bin/predict.sge $TD_OPT $MOONLIGHT_OPT $AI_COND_OPT $CLUSTER_DATA_DIR $PHASE effusion.SupervisedNetworkMethod


#### No pseudocounts

    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "td.ai_cond.no_pseudocounts" --pseudocount_weight 0 $TD_OPT $MOONLIGHT_OPT $AI_COND_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod

    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "bu.ai_cond.no_pseudocounts" --pseudocount_weight 0 $BU_OPT $NONEGS_OPT $AI_COND_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod

#### Not weighted

    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "td.ai_cond.not_weighted" --no_weighted_counts $TD_OPT $MOONLIGHT_OPT $AI_COND_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod

    qsub -t 1-$NUM_QUERIES -hold_jid_ad $BUILD_JID $EFFUSION_DIR/bin/predict.sge --experiment_name "bu.ai_cond.not_weighted" --no_weighted_counts $BU_OPT $NONEGS_OPT $AI_COND_OPT $CLUSTER_DATA_DIR $PHASE effusion.SSMethod

# Evaluate on workstation

    $CLUSTER_PYTHON $EFFUSION_DIR/bin/effuse.py --log_to_stderr $DATA_DIR test postprocess