import random

import configargparse
import os
from sqlalchemy import distinct, alias

import effusion


# we could exclude training annotations and pick from new annotations
# OR we could exclude training proteins and pick from new proteins

def main():
    for phase in effusion.dataset.phases:
        withheld_date = effusion.dataset.cutoff_dates[effusion.dataset.roles[phase]['training']]
        cutoff_date = effusion.dataset.cutoff_dates[effusion.dataset.roles[phase]['evaluation']]
        print withheld_date, '-', cutoff_date

        q = effusion.dataset.database_session.query(distinct(effusion.Annotation.uniprot).label('uniprot'))
        q = q.filter(effusion.Annotation.date > withheld_date).filter(effusion.Annotation.date <= cutoff_date)
        q = q.filter(effusion.Annotation.value == True).filter(effusion.Annotation.source.in_(('direct', 'implied')))

        if effusion.args.mf_only:
            q = q.join(effusion.GoTerm).filter(effusion.GoTerm.aspect == effusion.GoAspectEnum.molecular_function)

        if effusion.args.ida_only:
            q = q.filter(effusion.Annotation.value == True).filter(
                effusion.Annotation.evidence_code == 'IDA')
        uniprots_with_new_annotation = {r.uniprot for r in q}
        print 'uniprots with new annotation: %d' % len(uniprots_with_new_annotation)

        go_terms_alias = alias(effusion.GoTerm)
        uniprots_with_new_catalytic_annotation = {r.uniprot for r in
                                                  q.join(go_terms_alias).filter(go_terms_alias.c.catalytic == True)}
        print 'uniprots with new catalytic annotation: %d' % len(uniprots_with_new_catalytic_annotation)

        if args.num > len(uniprots_with_new_annotation):
            evaluation_proteins = sorted(uniprots_with_new_annotation, key=lambda x: random.random())
        else:
            evaluation_proteins = random.sample(uniprots_with_new_annotation, args.num)

        out_file_path = os.path.join(effusion.args.output_dir, 'evaluation_proteins.%s.txt' % phase)
        with open(out_file_path, 'w') as of:
            for p in evaluation_proteins:
                of.write('%s\n' % p)


if __name__ == '__main__':
    parser = configargparse.get_argument_parser()
    parser.add_argument('dataset', action='store')
    parser.add_argument('num', type=int,
                        help='number of randomly selected proteins from the withheld time period to use for evaluation')
    parser.add_argument('--ida_only', action='store_true')
    parser.add_argument('--mf_only', action='store_true')

    parser.add_argument('output_dir', type=str)
    args = parser.parse_args()
    effusion.args = args
    effusion.dataset.init(args.dataset)

    main()
