from __future__ import division

import cStringIO
import logging
import subprocess
import tempfile

import configargparse
import os
from Bio import SeqIO

import effusion


def make_goa_blast_db(goa_fasta_file, db_out):
    cmd = "%s -in %s -dbtype prot -parse_seqids -out %s -title blast_goa" % (
        effusion.args.makeblastdb_bin,
        goa_fasta_file.name,
        db_out)
    subprocess.check_call(cmd, stdout=None, stderr=None, shell=True)


def make_goa_diamond_db(goa_fasta_file, db_out):
    cmd = "%s makedb --in %s --db %s" % (
        effusion.args.diamond_bin,
        goa_fasta_file.name,
        db_out)
    subprocess.check_call(cmd, stdout=None, stderr=None, shell=True)


def write_fasta_for_accessions(uniprots, file):
    seq_records = get_seq_records_for_uniprots_batch(uniprots)
    SeqIO.write(seq_records, file, "fasta")


def get_seq_records_for_uniprots_batch(accessions):
    with tempfile.NamedTemporaryFile(delete=False, dir=effusion.args.tmp_dir) as accesssions_file:
        for accession in accessions:
            accesssions_file.write("%s\n" % accession)
    cmd = "%s -db %s -entry_batch %s -outfmt %%f" % (
        effusion.args.blastdbcmd_bin, effusion.args.uniprot_db,
        accesssions_file.name)
    my_popen = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
    stdout, stderr = my_popen.communicate()
    os.remove(accesssions_file.name)
    logging.error(stderr)
    records = SeqIO.parse(cStringIO.StringIO(stdout), "fasta")

    return list(records)


def main():
    for phase in effusion.dataset.phases:
        effusion.dataset.set_phase_and_role(phase, 'training')
        uniprots_with_evidence = effusion.annotation.query_uniprots_with_evidence()

        goa_fasta_file = tempfile.NamedTemporaryFile(delete=False, dir=effusion.args.tmp_dir)
        write_fasta_for_accessions(uniprots_with_evidence, goa_fasta_file)
        goa_fasta_file.close()

        if not effusion.args.skip_blast:
            db_out = os.path.join(effusion.args.output_dir, 'goa.%s' % effusion.dataset.dataset_cutoff_name)
            make_goa_blast_db(goa_fasta_file, db_out)

        if not effusion.args.skip_diamond:
            db_out = os.path.join(effusion.args.output_dir, 'diamond_goa.%s' % effusion.dataset.dataset_cutoff_name)
            make_goa_diamond_db(goa_fasta_file, db_out)


if __name__ == '__main__':
    parser = configargparse.get_argument_parser()
    parser.add_argument('dataset', action='store')
    parser.add_argument('output_dir', type=str)
    parser.add_argument('--skip-blast', action='store_true')
    parser.add_argument('--skip-diamond', action='store_true')

    args = parser.parse_args()
    effusion.args = args
    effusion.dataset.init(effusion.args.dataset)

    main()
