from __future__ import division

import multiprocessing
import random
import sys

import configargparse
from sqlalchemy import create_engine, Index
from sqlalchemy.orm import scoped_session, sessionmaker

import effusion

num_processed = multiprocessing.Value('i', 0)

# use a pandas table or numpy array for this?
# (go_kin, pnp, this_value)
contingency_table_template = {
    (False, False, False): 0,
    (False, False, True): 0,
    (False, True, False): 0,
    (False, True, True): 0,
    (True, False, False): 0,
    (True, False, True): 0,
    (True, True, False): 0,
    (True, True, True): 0,
}


def main():
    engine_string = "sqlite+pysqlite:///%s" % args.out_db
    engine = create_engine(engine_string,
                           echo_pool=False,
                           echo=False)

    session_factory = sessionmaker(bind=engine, autoflush=False, expire_on_commit=False)
    Session = scoped_session(session_factory)
    session = Session()

    effusion.ProteinNetworkParent.__table__.create(bind=engine)

    for phase in effusion.dataset.phases:
        effusion.dataset.set_phase_and_role(phase, 'training')

        uniprots = effusion.annotation.query_uniprots_with_evidence()
        sys.stderr.write('%d uniprots with evidence\n' % len(uniprots))
        print len(uniprots)

        if 'sample' in effusion.args:
            uniprots = set(random.sample(uniprots, k=len(uniprots))[0:effusion.args.sample])

        for edge_type in ('blast', 'string'):
            # todo make this a map instead
            if edge_type == 'blast':
                parents_map = effusion.get_annotated_diamond_parents(uniprots)
            elif edge_type == 'string':
                parents_map = effusion.get_annotated_string_parents(uniprots)
            else:
                raise

            for i, (uniprot, parent_uniprot) in enumerate(parents_map.iteritems()):
                protein_network_parent = effusion.ProteinNetworkParent(effusion.dataset.dataset_cutoff_name, edge_type,
                                                                       uniprot, parent_uniprot)
                session.add(protein_network_parent)
            session.commit()

    Index('ix_protein_network_parent_table_dataset_name', effusion.ProteinNetworkParent.dataset_name).create(engine)
    Index('ix_protein_network_parent_table_edge_type', effusion.ProteinNetworkParent.edge_type).create(engine)
    Index('ix_protein_network_parent_table_uniprot', effusion.ProteinNetworkParent.uniprot).create(engine)
    Index('ix_protein_network_parent_table_parent_uniprot', effusion.ProteinNetworkParent.parent_uniprot).create(engine)


if __name__ == '__main__':
    parser = effusion.config.get_argument_parser()
    parser.add_argument('--sample', action='store', type=int)
    parser.add_argument('dataset', action='store')
    parser.add_argument('out_db', type=str)

    args = effusion.config.parse_args(parser)

    effusion.args = args
    effusion.dataset.init(effusion.args.dataset)

    main()
